summaryrefslogtreecommitdiff
path: root/board/cr50/board.h
diff options
context:
space:
mode:
Diffstat (limited to 'board/cr50/board.h')
-rw-r--r--board/cr50/board.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/cr50/board.h b/board/cr50/board.h
index 69e2a5d1a7..bf54ba7c9f 100644
--- a/board/cr50/board.h
+++ b/board/cr50/board.h
@@ -426,10 +426,10 @@ void board_start_ite_sync(void);
/*
* Board specific function (needs information about pinmux settings) which
* allows to take the i2cs controller out of the 'wedged' state where the
* master stopped i2c access mid transaction and the slave is holding SDA low,
*/
-void board_unwedge_i2cs(void);
+void board_unwedge_i2cp(void);
int board_in_prod_mode(void);
@@ -426,10 +426,10 @@ void board_start_ite_sync(void);
/*
* Board specific function (needs information about pinmux settings) which
- * allows to take the i2cs controller out of the 'wedged' state where the
+ * allows to take the i2cp controller out of the 'wedged' state where the
* master stopped i2c access mid transaction and the slave is holding SDA low,
*/